@@ -39,9 +39,8 @@ class SearchEngineImpl2 implements SearchEngine {
   @override
   Future<List<SearchMatch>> searchMemberDeclarations(String name) async {
     List<SearchMatch> allDeclarations = [];
-    RegExp regExp = new RegExp('^$name\$');
     for (AnalysisDriver driver in _drivers) {
-      List<Element> elements = await driver.search.classMembers(regExp);
+      List<Element> elements = await driver.search.classMembers(name);
       allDeclarations.addAll(elements.map(_SearchMatch.forElement));
     }
     return allDeclarations;
@@ -153,6 +152,19 @@ class _SearchMatch implements SearchMatch {
     return buffer.toString();
   }
 
+  static _SearchMatch forElement(Element element) {
+    return new _SearchMatch(
+        element.source.fullName,
+        element.librarySource,
+        element.source,
+        element.library,
+        element,
+        true,
+        true,
+        MatchKind.DECLARATION,
+        new SourceRange(element.nameOffset, element.nameLength));
+  }
+
   static _SearchMatch forSearchResult(SearchResult result) {
     Element enclosingElement = result.enclosingElement;
     return new _SearchMatch(
@@ -167,19 +179,6 @@ class _SearchMatch implements SearchMatch {
         new SourceRange(result.offset, result.length));
   }
 
-  static _SearchMatch forElement(Element element) {
-    return new _SearchMatch(
-        element.source.fullName,
-        element.librarySource,
-        element.source,
-        element.library,
-        element,
-        true,
-        true,
-        MatchKind.DECLARATION,
-        new SourceRange(element.nameOffset, element.nameLength));
-  }
-
   static MatchKind toMatchKind(SearchResultKind kind) {
     if (kind == SearchResultKind.READ) {
       return MatchKind.READ;
