@@ -146,6 +146,14 @@ class SingleContextManager implements ContextManager {
     return null;
   }
 
+  @override
+  Folder getContextFolderFor(String path) {
+    if (isInAnalysisRoot(path)) {
+      return contextFolder;
+    }
+    return null;
+  }
+
   @override
   AnalysisDriver getDriverFor(String path) {
     throw new UnimplementedError(
