@@ -4,11 +4,12 @@
 
 library test.analysis.notification_analysis_options_test;
 
-import 'package:analysis_server/plugin/protocol/protocol.dart';
+import 'package:analysis_server/plugin/protocol/protocol.dart'
+    hide AnalysisOptions;
 import 'package:analysis_server/src/constants.dart';
 import 'package:analysis_server/src/domain_analysis.dart';
 import 'package:analyzer/src/generated/engine.dart';
-import 'package:analyzer/src/services/lint.dart';
+import 'package:linter/src/rules.dart';
 import 'package:test/test.dart';
 import 'package:test_reflective_loader/test_reflective_loader.dart';
 
@@ -19,6 +20,8 @@ main() {
   defineReflectiveSuite(() {
     defineReflectiveTests(NewAnalysisOptionsFileNotificationTest);
     defineReflectiveTests(OldAnalysisOptionsFileNotificationTest);
+    defineReflectiveTests(NewAnalysisOptionsFileNotificationTest_Driver);
+    defineReflectiveTests(OldAnalysisOptionsFileNotificationTest_Driver);
   });
 }
 
@@ -39,8 +42,6 @@ main() {
 
   String get optionsFilePath;
 
-  AnalysisContext get testContext => server.getContainingContext(testFile);
-
   List<AnalysisError> get testFileErrors => filesErrors[testFile];
 
   void addOptionsFile(String contents) {
@@ -74,6 +75,7 @@ analyzer:
 
   @override
   void setUp() {
+    registerLintRules();
     super.setUp();
     server.handlers = [new AnalysisDomainHandler(server)];
   }
@@ -103,9 +105,14 @@ main() {
     await waitForTasksFinished();
 
     // Verify options file.
-    expect(optionsFileErrors, isEmpty);
+    if (!enableNewAnalysisDriver) {
+      // TODO(brianwilkerson) Implement options file analysis in the new driver.
+      expect(optionsFileErrors, isNotNull);
+      expect(optionsFileErrors, isEmpty);
+    }
 
     // Verify test file.
+    expect(testFileErrors, isNotNull);
     expect(testFileErrors, isEmpty);
   }
 
@@ -127,9 +134,14 @@ main() {
     await waitForTasksFinished();
 
     // Verify options file.
-    expect(optionsFileErrors, isEmpty);
+    if (!enableNewAnalysisDriver) {
+      // TODO(brianwilkerson) Implement options file analysis in the new driver.
+      expect(optionsFileErrors, isNotNull);
+      expect(optionsFileErrors, isEmpty);
+    }
 
     // Verify test file.
+    expect(testFileErrors, isNotNull);
     expect(testFileErrors, isEmpty);
 
     addOptionsFile('''
@@ -142,7 +154,10 @@ analyzer:
     await waitForTasksFinished();
 
     // Verify options file.
-    expect(optionsFileErrors, isEmpty);
+    if (!enableNewAnalysisDriver) {
+      // TODO(brianwilkerson) Implement options file analysis in the new driver.
+      expect(optionsFileErrors, isEmpty);
+    }
 
     // Verify test file.
     expect(testFileErrors, hasLength(1));
@@ -187,9 +202,12 @@ linter:
 
     await waitForTasksFinished();
 
-    expect(optionsFileErrors, hasLength(1));
-    expect(optionsFileErrors.first.severity, AnalysisErrorSeverity.WARNING);
-    expect(optionsFileErrors.first.type, AnalysisErrorType.STATIC_WARNING);
+    if (!enableNewAnalysisDriver) {
+      // TODO(brianwilkerson) Implement options file analysis in the new driver.
+      expect(optionsFileErrors, hasLength(1));
+      expect(optionsFileErrors.first.severity, AnalysisErrorSeverity.WARNING);
+      expect(optionsFileErrors.first.type, AnalysisErrorType.STATIC_WARNING);
+    }
   }
 
   test_options_file_added() async {
@@ -221,9 +239,13 @@ linter:
 
     await waitForTasksFinished();
 
-    expect(optionsFileErrors, hasLength(1));
-    expect(optionsFileErrors.first.severity, AnalysisErrorSeverity.ERROR);
-    expect(optionsFileErrors.first.type, AnalysisErrorType.COMPILE_TIME_ERROR);
+    if (!enableNewAnalysisDriver) {
+      // TODO(brianwilkerson) Implement options file analysis in the new driver.
+      expect(optionsFileErrors, hasLength(1));
+      expect(optionsFileErrors.first.severity, AnalysisErrorSeverity.ERROR);
+      expect(
+          optionsFileErrors.first.type, AnalysisErrorType.COMPILE_TIME_ERROR);
+    }
   }
 
   test_options_file_removed() async {
@@ -287,14 +309,15 @@ linter:
   }
 
   void verifyLintsEnabled(List<String> lints) {
-    expect(testContext.analysisOptions.lint, true);
-    var rules = getLints(testContext).map((rule) => rule.name);
+    AnalysisOptions options = analysisOptions;
+    expect(options.lint, true);
+    var rules = options.lintRules.map((rule) => rule.name);
     expect(rules, unorderedEquals(lints));
   }
 
   verifyStrongMode({bool enabled}) {
     // Verify strong-mode enabled.
-    expect(testContext.analysisOptions.strongMode, enabled);
+    expect(analysisOptions.strongMode, enabled);
 
     if (enabled) {
       // Should produce a type warning.
@@ -311,11 +334,35 @@ linter:
 @reflectiveTest
 class NewAnalysisOptionsFileNotificationTest
     extends AnalysisOptionsFileNotificationTest {
+  @override
   String get optionsFilePath => '$projectPath/analysis_options.yaml';
 }
 
+@reflectiveTest
+class NewAnalysisOptionsFileNotificationTest_Driver
+    extends NewAnalysisOptionsFileNotificationTest {
+  @override
+  void setUp() {
+    enableNewAnalysisDriver = true;
+    generateSummaryFiles = true;
+    super.setUp();
+  }
+}
+
 @reflectiveTest
 class OldAnalysisOptionsFileNotificationTest
     extends AnalysisOptionsFileNotificationTest {
+  @override
   String get optionsFilePath => '$projectPath/.analysis_options';
 }
+
+@reflectiveTest
+class OldAnalysisOptionsFileNotificationTest_Driver
+    extends OldAnalysisOptionsFileNotificationTest {
+  @override
+  void setUp() {
+    enableNewAnalysisDriver = true;
+    generateSummaryFiles = true;
+    super.setUp();
+  }
+}
