@@ -933,4 +933,100 @@ void main() {
     await prepareNavigation();
     assertNoRegionAt('void');
   }
+
+  test_var_declaredVariable() async {
+    addTestFile('''
+class C {}
+f(List<C> items) {
+  for (var item in items) {}
+}
+''');
+    await prepareNavigation();
+    assertHasRegionTarget('var', 'C {}');
+    expect(testTarget.kind, ElementKind.CLASS);
+  }
+
+  test_var_localVariable_multiple_inferred_different() async {
+    addTestFile('''
+class A {}
+class B {}
+void f() {
+  var a = new A(), b = new B();
+}
+''');
+    await prepareNavigation();
+    assertNoRegionAt('var');
+  }
+
+  test_var_localVariable_multiple_inferred_same() async {
+    addTestFile('''
+class C {}
+void f() {
+  var a = new C(), b = new C();
+}
+''');
+    await prepareNavigation();
+    assertHasRegionTarget('var', 'C {}');
+    expect(testTarget.kind, ElementKind.CLASS);
+  }
+
+  test_var_localVariable_single_inferred() async {
+    addTestFile('''
+class C {}
+f() {
+  var c = new C();
+}
+''');
+    await prepareNavigation();
+    assertHasRegionTarget('var', 'C {}');
+    expect(testTarget.kind, ElementKind.CLASS);
+  }
+
+  test_var_localVariable_single_notInferred() async {
+    addTestFile('''
+f() {
+  var x;
+}
+''');
+    await prepareNavigation();
+    assertNoRegionAt('var');
+  }
+
+  test_var_topLevelVariable_multiple_inferred_different() async {
+    addTestFile('''
+class A {}
+class B {}
+var a = new A(), b = new B();
+''');
+    await prepareNavigation();
+    assertNoRegionAt('var');
+  }
+
+  test_var_topLevelVariable_multiple_inferred_same() async {
+    addTestFile('''
+class C {}
+var a = new C(), b = new C();
+''');
+    await prepareNavigation();
+    assertHasRegionTarget('var', 'C {}');
+    expect(testTarget.kind, ElementKind.CLASS);
+  }
+
+  test_var_topLevelVariable_single_inferred() async {
+    addTestFile('''
+class C {}
+var c = new C();
+''');
+    await prepareNavigation();
+    assertHasRegionTarget('var', 'C {}');
+    expect(testTarget.kind, ElementKind.CLASS);
+  }
+
+  test_var_topLevelVariable_single_notInferred() async {
+    addTestFile('''
+var x;
+''');
+    await prepareNavigation();
+    assertNoRegionAt('var');
+  }
 }
