@@ -2,8 +2,6 @@
 // for details. All rights reserved. Use of this source code is governed by a
 // BSD-style license that can be found in the LICENSE file.
 
-library test.integration.analysis.get.errors;
-
 import 'dart:async';
 import 'dart:io';
 
@@ -19,6 +17,7 @@ import '../integration_tests.dart';
 main() {
   defineReflectiveSuite(() {
     defineReflectiveTests(AnalysisDomainGetErrorsTest);
+    defineReflectiveTests(AnalysisDomainGetErrorsTest_Driver);
   });
 }
 
@@ -26,11 +25,8 @@ main() {
  * Tests that when an SDK path is specified on the command-line (via the `--sdk`
  * argument) that the specified SDK is used.
  */
-@reflectiveTest
-class AnalysisDomainGetErrorsTest
+class AbstractAnalysisDomainGetErrorsTest
     extends AbstractAnalysisServerIntegrationTest {
-  AnalysisDomainGetErrorsTest();
-
   String createNonStandardSdk() {
     MockSdkLibrary fakeLibrary =
         new MockSdkLibrary('dart:fake', '/lib/fake/fake.dart', '');
@@ -97,3 +93,13 @@ import 'dart:fake';
     expect(errors[0].code, 'unused_import');
   }
 }
+
+@reflectiveTest
+class AnalysisDomainGetErrorsTest extends AbstractAnalysisDomainGetErrorsTest {}
+
+@reflectiveTest
+class AnalysisDomainGetErrorsTest_Driver
+    extends AbstractAnalysisDomainGetErrorsTest {
+  @override
+  bool get enableNewAnalysisDriver => true;
+}
