@@ -9,11 +9,10 @@ import 'package:test_reflective_loader/test_reflective_loader.dart';
 import 'analysis_options_test.dart' as analysis_options_test;
 import 'error_driver_test.dart' as error_driver_test;
 import 'error_test.dart' as error_test;
-import 'get_errors_after_analysis_test.dart' as get_errors_after_analysis_test;
-import 'get_errors_before_analysis_test.dart'
-    as get_errors_before_analysis_test;
 import 'get_errors_nonStandard_sdk.dart' as get_errors_nonStandard_sdk;
+import 'get_errors_test.dart' as get_errors_test;
 import 'get_hover_test.dart' as get_hover_test;
+import 'get_navigation_test.dart' as get_navigation_test;
 import 'highlights_test.dart' as highlights_test;
 import 'highlights_test2.dart' as highlights_test2;
 import 'lint_driver_test.dart' as lint_driver_test;
@@ -25,9 +24,12 @@ import 'overrides_test.dart' as overrides_test;
 import 'package_root_test.dart' as package_root_test;
 import 'reanalyze_concurrent_test.dart' as reanalyze_concurrent_test;
 import 'reanalyze_test.dart' as reanalyze_test;
+import 'set_analysis_roots_test.dart' as set_analysis_roots_test;
+import 'set_subscriptions_test.dart' as set_subscriptions_test;
 import 'update_content_driver_test.dart' as update_content_driver_test;
 import 'update_content_list_test.dart' as update_content_list_test;
 import 'update_content_test.dart' as update_content_test;
+import 'update_options_test.dart' as update_options_test;
 
 /**
  * Utility for manually running all integration tests.
@@ -37,10 +39,10 @@ main() {
     analysis_options_test.main();
     error_driver_test.main();
     error_test.main();
-    get_errors_after_analysis_test.main();
-    get_errors_before_analysis_test.main();
+    get_errors_test.main();
     get_errors_nonStandard_sdk.main();
     get_hover_test.main();
+    get_navigation_test.main();
     highlights_test.main();
     highlights_test2.main();
     lint_driver_test.main();
@@ -52,8 +54,11 @@ main() {
     package_root_test.main();
     reanalyze_concurrent_test.main();
     reanalyze_test.main();
+    set_analysis_roots_test.main();
+    set_subscriptions_test.main();
     update_content_driver_test.main();
     update_content_test.main();
     update_content_list_test.main();
+    update_options_test.main();
   }, name: 'analysis');
 }
