@@ -4,9 +4,8 @@
 
 library test.integration.server.all;
 
-import 'package:unittest/unittest.dart';
+import 'package:test_reflective_loader/test_reflective_loader.dart';
 
-import '../../utils.dart';
 import 'get_version_test.dart' as get_version_test;
 import 'set_subscriptions_invalid_service_test.dart'
     as set_subscriptions_invalid_service_test;
@@ -18,12 +17,11 @@ import 'status_test.dart' as status_test;
  * Utility for manually running all integration tests.
  */
 main() {
-  initializeTestEnvironment();
-  group('server', () {
+  defineReflectiveSuite(() {
     get_version_test.main();
     set_subscriptions_test.main();
     set_subscriptions_invalid_service_test.main();
     shutdown_test.main();
     status_test.main();
-  });
+  }, name: 'server');
 }
