@@ -15,6 +15,7 @@ import 'abstract_search_domain.dart';
 main() {
   defineReflectiveSuite(() {
     defineReflectiveTests(MemberReferencesTest);
+    defineReflectiveTests(MemberReferencesTest_Driver);
   });
 }
 
@@ -113,3 +114,12 @@ mainUnresolved(a, b) {
     assertHasRef(SearchResultKind.INVOCATION, 'foo(20)', true);
   }
 }
+
+@reflectiveTest
+class MemberReferencesTest_Driver extends MemberReferencesTest {
+  @override
+  void setUp() {
+    enableNewAnalysisDriver = true;
+    super.setUp();
+  }
+}
