@@ -15,6 +15,7 @@ import 'completion_contributor_util.dart';
 main() {
   defineReflectiveSuite(() {
     defineReflectiveTests(LibraryPrefixContributorTest);
+    defineReflectiveTests(LibraryPrefixContributorTest_Driver);
   });
 }
 
@@ -375,3 +376,9 @@ main() {new ^ String x = "hello";}''');
     assertNoSuggestions();
   }
 }
+
+@reflectiveTest
+class LibraryPrefixContributorTest_Driver extends LibraryPrefixContributorTest {
+  @override
+  bool get enableNewAnalysisDriver => true;
+}
