@@ -18,6 +18,8 @@ main() {
   defineReflectiveSuite(() {
     defineReflectiveTests(UriContributorTest);
     defineReflectiveTests(UriContributorWindowsTest);
+    defineReflectiveTests(UriContributorTest_Driver);
+    defineReflectiveTests(UriContributorWindowsTest_Driver);
   });
 }
 
@@ -462,6 +464,12 @@ class UriContributorTest extends DartCompletionContributorTest {
   }
 }
 
+@reflectiveTest
+class UriContributorTest_Driver extends UriContributorTest {
+  @override
+  bool get enableNewAnalysisDriver => true;
+}
+
 @reflectiveTest
 class UriContributorWindowsTest extends DartCompletionContributorTest {
   @override
@@ -628,6 +636,12 @@ class UriContributorWindowsTest extends DartCompletionContributorTest {
   }
 }
 
+@reflectiveTest
+class UriContributorWindowsTest_Driver extends UriContributorWindowsTest {
+  @override
+  bool get enableNewAnalysisDriver => true;
+}
+
 class _TestWinResourceProvider extends MemoryResourceProvider {
   @override
   Context get pathContext => windows;
