@@ -14,13 +14,14 @@ import 'abstract_rename.dart';
 main() {
   defineReflectiveSuite(() {
     defineReflectiveTests(RenameLocalTest);
+    defineReflectiveTests(RenameLocalTest_Driver);
   });
 }
 
 @reflectiveTest
 class RenameLocalTest extends RenameRefactoringTest {
   test_checkFinalConditions_hasLocalFunction_after() async {
-    indexTestUnit('''
+    await indexTestUnit('''
 main() {
   int test = 0;
   newName() => 1;
@@ -36,7 +37,7 @@ main() {
   }
 
   test_checkFinalConditions_hasLocalFunction_before() async {
-    indexTestUnit('''
+    await indexTestUnit('''
 main() {
   newName() => 1;
   int test = 0;
@@ -51,7 +52,7 @@ main() {
   }
 
   test_checkFinalConditions_hasLocalVariable_after() async {
-    indexTestUnit('''
+    await indexTestUnit('''
 main() {
   int test = 0;
   var newName = 1;
@@ -69,7 +70,7 @@ main() {
   }
 
   test_checkFinalConditions_hasLocalVariable_before() async {
-    indexTestUnit('''
+    await indexTestUnit('''
 main() {
   var newName = 1;
   int test = 0;
@@ -84,8 +85,8 @@ main() {
         expectedContextSearch: 'newName = 1;');
   }
 
-  test_checkFinalConditions_hasLocalVariable_otherBlock() {
-    indexTestUnit('''
+  test_checkFinalConditions_hasLocalVariable_otherBlock() async {
+    await indexTestUnit('''
 main() {
   {
     var newName = 1;
@@ -101,8 +102,8 @@ main() {
     return assertRefactoringConditionsOK();
   }
 
-  test_checkFinalConditions_hasLocalVariable_otherForEachLoop() {
-    indexTestUnit('''
+  test_checkFinalConditions_hasLocalVariable_otherForEachLoop() async {
+    await indexTestUnit('''
 main() {
   for (int newName in []) {}
   for (int test in []) {}
@@ -114,8 +115,8 @@ main() {
     return assertRefactoringConditionsOK();
   }
 
-  test_checkFinalConditions_hasLocalVariable_otherForLoop() {
-    indexTestUnit('''
+  test_checkFinalConditions_hasLocalVariable_otherForLoop() async {
+    await indexTestUnit('''
 main() {
   for (int newName = 0; newName < 10; newName++) {}
   for (int test = 0; test < 10; test++) {}
@@ -127,8 +128,8 @@ main() {
     return assertRefactoringConditionsOK();
   }
 
-  test_checkFinalConditions_hasLocalVariable_otherFunction() {
-    indexTestUnit('''
+  test_checkFinalConditions_hasLocalVariable_otherFunction() async {
+    await indexTestUnit('''
 main() {
   int test = 0;
 }
@@ -143,7 +144,7 @@ main2() {
   }
 
   test_checkFinalConditions_shadows_classMember() async {
-    indexTestUnit('''
+    await indexTestUnit('''
 class A {
   var newName = 1;
   main() {
@@ -163,19 +164,19 @@ class A {
   }
 
   test_checkFinalConditions_shadows_classMember_namedParameter() async {
-    indexTestUnit('''
+    await indexTestUnit('''
 class A {
-  foo({test: 1}) {
+  foo({test: 1}) { // in A
   }
 }
 class B extends A {
   var newName = 1;
-  foo({test: 2}) {
+  foo({test: 1}) {
     print(newName);
   }
 }
 ''');
-    createRenameRefactoringAtString('test: 1}');
+    createRenameRefactoringAtString('test: 1}) { // in A');
     // check status
     refactoring.newName = 'newName';
     RefactoringStatus status = await refactoring.checkFinalConditions();
@@ -185,8 +186,8 @@ class B extends A {
         expectedContextSearch: 'newName);');
   }
 
-  test_checkFinalConditions_shadows_classMemberOK_qualifiedReference() {
-    indexTestUnit('''
+  test_checkFinalConditions_shadows_classMemberOK_qualifiedReference() async {
+    await indexTestUnit('''
 class A {
   var newName = 1;
   main() {
@@ -201,8 +202,8 @@ class A {
     return assertRefactoringConditionsOK();
   }
 
-  test_checkFinalConditions_shadows_OK_namedParameterReference() {
-    indexTestUnit('''
+  test_checkFinalConditions_shadows_OK_namedParameterReference() async {
+    await indexTestUnit('''
 void f({newName}) {}
 main() {
   var test = 0;
@@ -216,7 +217,7 @@ main() {
   }
 
   test_checkFinalConditions_shadows_topLevelFunction() async {
-    indexTestUnit('''
+    await indexTestUnit('''
 newName() {}
 main() {
   var test = 0;
@@ -231,13 +232,13 @@ main() {
         expectedContextSearch: 'newName(); // ref');
   }
 
-  test_checkNewName_FunctionElement() {
-    indexTestUnit('''
+  test_checkNewName_FunctionElement() async {
+    await indexTestUnit('''
 main() {
-  int test() {}
+  int test() => 0;
 }
 ''');
-    createRenameRefactoringAtString('test() {}');
+    createRenameRefactoringAtString('test() => 0;');
     // null
     refactoring.newName = null;
     assertRefactoringStatus(
@@ -248,8 +249,8 @@ main() {
     assertRefactoringStatusOK(refactoring.checkNewName());
   }
 
-  test_checkNewName_LocalVariableElement() {
-    indexTestUnit('''
+  test_checkNewName_LocalVariableElement() async {
+    await indexTestUnit('''
 main() {
   int test = 0;
 }
@@ -270,8 +271,8 @@ main() {
     assertRefactoringStatusOK(refactoring.checkNewName());
   }
 
-  test_checkNewName_ParameterElement() {
-    indexTestUnit('''
+  test_checkNewName_ParameterElement() async {
+    await indexTestUnit('''
 main(test) {
 }
 ''');
@@ -286,8 +287,8 @@ main(test) {
     assertRefactoringStatusOK(refactoring.checkNewName());
   }
 
-  test_createChange_localFunction() {
-    indexTestUnit('''
+  test_createChange_localFunction() async {
+    await indexTestUnit('''
 main() {
   int test() => 0;
   print(test);
@@ -309,8 +310,8 @@ main() {
 ''');
   }
 
-  test_createChange_localFunction_sameNameDifferenceScopes() {
-    indexTestUnit('''
+  test_createChange_localFunction_sameNameDifferenceScopes() async {
+    await indexTestUnit('''
 main() {
   {
     int test() => 0;
@@ -349,8 +350,8 @@ main() {
 ''');
   }
 
-  test_createChange_localVariable() {
-    indexTestUnit('''
+  test_createChange_localVariable() async {
+    await indexTestUnit('''
 main() {
   int test = 0;
   test = 1;
@@ -374,8 +375,8 @@ main() {
 ''');
   }
 
-  test_createChange_localVariable_sameNameDifferenceScopes() {
-    indexTestUnit('''
+  test_createChange_localVariable_sameNameDifferenceScopes() async {
+    await indexTestUnit('''
 main() {
   {
     int test = 0;
@@ -414,8 +415,8 @@ main() {
 ''');
   }
 
-  test_createChange_parameter() {
-    indexTestUnit('''
+  test_createChange_parameter() async {
+    await indexTestUnit('''
 myFunction({int test}) {
   test = 1;
   test += 2;
@@ -444,12 +445,12 @@ main() {
   }
 
   test_createChange_parameter_named_inOtherFile() async {
-    indexTestUnit('''
+    await indexTestUnit('''
 class A {
   A({test});
 }
 ''');
-    indexUnit(
+    await indexUnit(
         '/test2.dart',
         '''
 import 'test.dart';
@@ -478,7 +479,7 @@ main() {
   }
 
   test_createChange_parameter_named_updateHierarchy() async {
-    indexUnit(
+    await indexUnit(
         '/test2.dart',
         '''
 library test2;
@@ -493,7 +494,7 @@ class B extends A {
   }
 }
 ''');
-    indexTestUnit('''
+    await indexTestUnit('''
 import 'test2.dart';
 main() {
   new A().foo(test: 10);
@@ -541,8 +542,8 @@ class B extends A {
 ''');
   }
 
-  test_oldName() {
-    indexTestUnit('''
+  test_oldName() async {
+    await indexTestUnit('''
 main() {
   int test = 0;
 }
@@ -553,3 +554,9 @@ main() {
     expect(refactoring.oldName, 'test');
   }
 }
+
+@reflectiveTest
+class RenameLocalTest_Driver extends RenameLocalTest {
+  @override
+  bool get enableNewAnalysisDriver => true;
+}
