@@ -6,6 +6,7 @@ library test.src;
 
 import 'package:test_reflective_loader/test_reflective_loader.dart';
 
+import 'plugin/test_all.dart' as plugin_all;
 import 'utilities/test_all.dart' as utilities_all;
 
 /**
@@ -13,6 +14,7 @@ import 'utilities/test_all.dart' as utilities_all;
  */
 main() {
   defineReflectiveSuite(() {
+    plugin_all.main();
     utilities_all.main();
   }, name: 'analysis_server');
 }
