@@ -2,16 +2,12 @@
 // for details. All rights reserved. Use of this source code is governed by a
 // BSD-style license that can be found in the LICENSE file.
 
-library analysis_server.test.src.utilities.change_builder_core_test;
-
 import 'package:analysis_server/plugin/protocol/protocol.dart';
 import 'package:analysis_server/src/provisional/edit/utilities/change_builder_core.dart';
 import 'package:analysis_server/src/utilities/change_builder_core.dart';
 import 'package:test/test.dart';
 import 'package:test_reflective_loader/test_reflective_loader.dart';
 
-import '../../domain_execution_test.dart';
-
 main() {
   defineReflectiveSuite(() {
     defineReflectiveTests(ChangeBuilderImplTest);
@@ -23,15 +19,15 @@ main() {
 
 @reflectiveTest
 class ChangeBuilderImplTest {
-  void test_createFileEditBuilder() {
+  test_createFileEditBuilder() async {
     ChangeBuilderImpl builder = new ChangeBuilderImpl();
-    TestSource source = new TestSource('/test.dart');
+    String path = '/test.dart';
     int timeStamp = 54;
     FileEditBuilderImpl fileEditBuilder =
-        builder.createFileEditBuilder(source, timeStamp);
+        await builder.createFileEditBuilder(path, timeStamp);
     expect(fileEditBuilder, new isInstanceOf<FileEditBuilder>());
     SourceFileEdit fileEdit = fileEditBuilder.fileEdit;
-    expect(fileEdit.file, source.fullName);
+    expect(fileEdit.file, path);
     expect(fileEdit.fileStamp, timeStamp);
   }
 
@@ -52,10 +48,10 @@ class ChangeBuilderImplTest {
     expect(sourceChange.selection, isNull);
   }
 
-  void test_sourceChange_oneChange() {
+  test_sourceChange_oneChange() async {
     ChangeBuilderImpl builder = new ChangeBuilderImpl();
-    TestSource source = new TestSource('/test.dart');
-    builder.addFileEdit(source, 0, (FileEditBuilder builder) {});
+    String path = '/test.dart';
+    await builder.addFileEdit(path, 0, (FileEditBuilder builder) {});
     builder.getLinkedEditGroup('a');
     SourceChange sourceChange = builder.sourceChange;
     expect(sourceChange, isNotNull);
@@ -68,13 +64,13 @@ class ChangeBuilderImplTest {
 
 @reflectiveTest
 class EditBuilderImplTest {
-  TestSource source = new TestSource('/test.dart');
+  String path = '/test.dart';
 
-  void test_addLinkedEdit() {
+  test_addLinkedEdit() async {
     ChangeBuilderImpl builder = new ChangeBuilderImpl();
     int offset = 10;
     String text = 'content';
-    builder.addFileEdit(source, 0, (FileEditBuilder builder) {
+    await builder.addFileEdit(path, 0, (FileEditBuilder builder) {
       builder.addInsertion(10, (EditBuilder builder) {
         builder.addLinkedEdit('a', (LinkedEditBuilder builder) {
           builder.write(text);
@@ -95,9 +91,9 @@ class EditBuilderImplTest {
     expect(positions[0].offset, offset);
   }
 
-  void test_createLinkedEditBuilder() {
+  test_createLinkedEditBuilder() async {
     ChangeBuilderImpl builder = new ChangeBuilderImpl();
-    builder.addFileEdit(source, 0, (FileEditBuilder builder) {
+    await builder.addFileEdit(path, 0, (FileEditBuilder builder) {
       builder.addInsertion(10, (EditBuilder builder) {
         LinkedEditBuilderImpl linkBuilder =
             (builder as EditBuilderImpl).createLinkedEditBuilder();
@@ -106,12 +102,12 @@ class EditBuilderImplTest {
     });
   }
 
-  void test_write() {
+  test_write() async {
     ChangeBuilderImpl builder = new ChangeBuilderImpl();
     int timeStamp = 93;
     int offset = 10;
     String text = 'write';
-    builder.addFileEdit(source, timeStamp, (FileEditBuilder builder) {
+    await builder.addFileEdit(path, timeStamp, (FileEditBuilder builder) {
       builder.addInsertion(offset, (EditBuilder builder) {
         builder.write(text);
       });
@@ -124,7 +120,7 @@ class EditBuilderImplTest {
     expect(fileEdits, hasLength(1));
     SourceFileEdit fileEdit = fileEdits[0];
     expect(fileEdit, isNotNull);
-    expect(fileEdit.file, source.fullName);
+    expect(fileEdit.file, path);
     expect(fileEdit.fileStamp, timeStamp);
 
     List<SourceEdit> edits = fileEdit.edits;
@@ -136,12 +132,12 @@ class EditBuilderImplTest {
     expect(edit.replacement, text);
   }
 
-  void test_writeln_withoutText() {
+  test_writeln_withoutText() async {
     ChangeBuilderImpl builder = new ChangeBuilderImpl();
     int timeStamp = 39;
     int offset = 52;
     int length = 12;
-    builder.addFileEdit(source, timeStamp, (FileEditBuilder builder) {
+    await builder.addFileEdit(path, timeStamp, (FileEditBuilder builder) {
       builder.addReplacement(offset, length, (EditBuilder builder) {
         builder.writeln();
       });
@@ -154,7 +150,7 @@ class EditBuilderImplTest {
     expect(fileEdits, hasLength(1));
     SourceFileEdit fileEdit = fileEdits[0];
     expect(fileEdit, isNotNull);
-    expect(fileEdit.file, source.fullName);
+    expect(fileEdit.file, path);
     expect(fileEdit.fileStamp, timeStamp);
 
     List<SourceEdit> edits = fileEdit.edits;
@@ -166,13 +162,13 @@ class EditBuilderImplTest {
     expect(edit.replacement == '\n' || edit.replacement == '\r\n', isTrue);
   }
 
-  void test_writeln_withText() {
+  test_writeln_withText() async {
     ChangeBuilderImpl builder = new ChangeBuilderImpl();
     int timeStamp = 39;
     int offset = 52;
     int length = 12;
     String text = 'writeln';
-    builder.addFileEdit(source, timeStamp, (FileEditBuilder builder) {
+    await builder.addFileEdit(path, timeStamp, (FileEditBuilder builder) {
       builder.addReplacement(offset, length, (EditBuilder builder) {
         builder.writeln(text);
       });
@@ -185,7 +181,7 @@ class EditBuilderImplTest {
     expect(fileEdits, hasLength(1));
     SourceFileEdit fileEdit = fileEdits[0];
     expect(fileEdit, isNotNull);
-    expect(fileEdit.file, source.fullName);
+    expect(fileEdit.file, path);
     expect(fileEdit.fileStamp, timeStamp);
 
     List<SourceEdit> edits = fileEdit.edits;
@@ -201,45 +197,45 @@ class EditBuilderImplTest {
 
 @reflectiveTest
 class FileEditBuilderImplTest {
-  TestSource source = new TestSource('/test.dart');
+  String path = '/test.dart';
 
-  void test_addInsertion() {
+  test_addInsertion() async {
     ChangeBuilderImpl builder = new ChangeBuilderImpl();
-    builder.addFileEdit(source, 0, (FileEditBuilder builder) {
+    await builder.addFileEdit(path, 0, (FileEditBuilder builder) {
       builder.addInsertion(10, (EditBuilder builder) {
         expect(builder, isNotNull);
       });
     });
   }
 
-  void test_addLinkedPosition() {
-    ChangeBuilderImpl changeBuilder = new ChangeBuilderImpl();
+  test_addLinkedPosition() async {
+    ChangeBuilderImpl builder = new ChangeBuilderImpl();
     String groupName = 'a';
-    changeBuilder.addFileEdit(source, 0, (FileEditBuilder builder) {
+    await builder.addFileEdit(path, 0, (FileEditBuilder builder) {
       builder.addLinkedPosition(3, 6, groupName);
     });
 
-    LinkedEditGroup group = changeBuilder.getLinkedEditGroup(groupName);
+    LinkedEditGroup group = builder.getLinkedEditGroup(groupName);
     List<Position> positions = group.positions;
     expect(positions, hasLength(1));
     Position position = positions[0];
-    expect(position.file, source.fullName);
+    expect(position.file, path);
     expect(position.offset, 3);
     expect(group.length, 6);
   }
 
-  void test_addReplacement() {
+  test_addReplacement() async {
     ChangeBuilderImpl builder = new ChangeBuilderImpl();
-    builder.addFileEdit(source, 0, (FileEditBuilder builder) {
+    await builder.addFileEdit(path, 0, (FileEditBuilder builder) {
       builder.addReplacement(4, 5, (EditBuilder builder) {
         expect(builder, isNotNull);
       });
     });
   }
 
-  void test_createEditBuilder() {
+  test_createEditBuilder() async {
     ChangeBuilderImpl builder = new ChangeBuilderImpl();
-    builder.addFileEdit(source, 0, (FileEditBuilder builder) {
+    await builder.addFileEdit(path, 0, (FileEditBuilder builder) {
       int offset = 4;
       int length = 5;
       EditBuilderImpl editBuilder =
@@ -255,12 +251,12 @@ class FileEditBuilderImplTest {
 
 @reflectiveTest
 class LinkedEditBuilderImplTest {
-  TestSource source = new TestSource('/test.dart');
+  String path = '/test.dart';
 
-  void test_addSuggestion() {
+  test_addSuggestion() async {
     String groupName = 'a';
     ChangeBuilderImpl builder = new ChangeBuilderImpl();
-    builder.addFileEdit(source, 0, (FileEditBuilder builder) {
+    await builder.addFileEdit(path, 0, (FileEditBuilder builder) {
       builder.addInsertion(10, (EditBuilder builder) {
         builder.addLinkedEdit(groupName, (LinkedEditBuilder builder) {
           builder.addSuggestion(LinkedEditSuggestionKind.TYPE, 'A');
@@ -272,10 +268,10 @@ class LinkedEditBuilderImplTest {
     expect(group.suggestions, hasLength(1));
   }
 
-  void test_addSuggestions() {
+  test_addSuggestions() async {
     String groupName = 'a';
     ChangeBuilderImpl builder = new ChangeBuilderImpl();
-    builder.addFileEdit(source, 0, (FileEditBuilder builder) {
+    await builder.addFileEdit(path, 0, (FileEditBuilder builder) {
       builder.addInsertion(10, (EditBuilder builder) {
         builder.addLinkedEdit(groupName, (LinkedEditBuilder builder) {
           builder.addSuggestions(LinkedEditSuggestionKind.TYPE, ['A', 'B']);
