@@ -6,10 +6,10 @@ library analyzer.src.task.dart_work_manager;
 
 import 'dart:collection';
 
+import 'package:analyzer/error/error.dart';
 import 'package:analyzer/src/context/cache.dart';
 import 'package:analyzer/src/generated/engine.dart'
     show AnalysisEngine, AnalysisErrorInfo, CacheState, InternalAnalysisContext;
-import 'package:analyzer/src/generated/error.dart';
 import 'package:analyzer/src/generated/source.dart';
 import 'package:analyzer/src/generated/utilities_collection.dart';
 import 'package:analyzer/src/task/dart.dart';
@@ -40,6 +40,7 @@ class DartWorkManager implements WorkManager {
     HINTS,
     LINTS,
     LIBRARY_UNIT_ERRORS,
+    RESOLVE_DIRECTIVES_ERRORS,
     RESOLVE_TYPE_NAMES_ERRORS,
     RESOLVE_TYPE_BOUNDS_ERRORS,
     RESOLVE_UNIT_ERRORS,
