@@ -162,8 +162,6 @@ class AbstractContextTest {
   void setUp() {
     List<Plugin> plugins = <Plugin>[];
     plugins.addAll(AnalysisEngine.instance.requiredPlugins);
-    plugins.add(AnalysisEngine.instance.commandLinePlugin);
-    plugins.add(AnalysisEngine.instance.optionsPlugin);
 
     ExtensionManager manager = new ExtensionManager();
     manager.processPlugins(plugins);
