@@ -15,7 +15,6 @@ import 'package:analyzer/src/dart/analysis/top_level_declaration.dart';
 import 'package:analyzer/src/generated/engine.dart'
     show AnalysisOptions, AnalysisOptionsImpl;
 import 'package:analyzer/src/generated/source.dart';
-import 'package:analyzer/src/util/fast_uri.dart';
 import 'package:convert/convert.dart';
 import 'package:crypto/crypto.dart';
 import 'package:test/test.dart';
@@ -63,6 +62,46 @@ class FileSystemStateTest {
         provider, sourceFactory, analysisOptions, new Uint32List(0));
   }
 
+  test_definedClassMemberNames() {
+    String path = _p('/aaa/lib/a.dart');
+    provider.newFile(
+        path,
+        r'''
+class A {
+  int a, b;
+  A();
+  A.c();
+  d() {}
+  get e => null;
+  set f(_) {}
+}
+class B {
+  g() {}
+}
+''');
+    FileState file = fileSystemState.getFileForPath(path);
+    expect(file.definedClassMemberNames,
+        unorderedEquals(['a', 'b', 'd', 'e', 'f', 'g']));
+  }
+
+  test_definedTopLevelNames() {
+    String path = _p('/aaa/lib/a.dart');
+    provider.newFile(
+        path,
+        r'''
+class A {}
+class B = Object with A;
+typedef C();
+D() {}
+get E => null;
+set F(_) {}
+var G, H;
+''');
+    FileState file = fileSystemState.getFileForPath(path);
+    expect(file.definedTopLevelNames,
+        unorderedEquals(['A', 'B', 'C', 'D', 'E', 'F', 'G', 'H']));
+  }
+
   test_exportedTopLevelDeclarations_export() {
     String a = _p('/aaa/lib/a.dart');
     String b = _p('/aaa/lib/b.dart');
@@ -262,7 +301,7 @@ class A2 {}
     String path = _p('/aaa/lib/a.dart');
     FileState file = fileSystemState.getFileForPath(path);
     expect(file.path, path);
-    expect(file.uri, FastUri.parse('package:aaa/a.dart'));
+    expect(file.uri, Uri.parse('package:aaa/a.dart'));
     expect(file.content, '');
     expect(file.contentHash, _md5(''));
     expect(_excludeSdk(file.importedFiles), isEmpty);
@@ -275,27 +314,51 @@ class A2 {}
     expect(file.unlinked.classes, isEmpty);
   }
 
-  test_getFileForPath_generatedFile() {
-    Uri uri = Uri.parse('package:aaa/foo.dart');
-    String templatePath = _p('/aaa/lib/foo.dart');
-    String generatedPath = _p('/generated/aaa/lib/foo.dart');
+  test_getFileForPath_hasLibraryDirective_hasPartOfDirective() {
+    String a = _p('/test/lib/a.dart');
+    provider.newFile(
+        a,
+        r'''
+library L;
+part of L;
+''');
+    FileState file = fileSystemState.getFileForPath(a);
+    expect(file.isPart, isFalse);
+  }
 
-    Source generatedSource = new _SourceMock();
-    when(generatedSource.fullName).thenReturn(generatedPath);
-    when(generatedSource.uri).thenReturn(uri);
+  test_getFileForPath_import_invalidUri() {
+    String a = _p('/aaa/lib/a.dart');
+    String a1 = _p('/aaa/lib/a1.dart');
+    String a2 = _p('/aaa/lib/a2.dart');
+    String a3 = _p('/aaa/lib/a3.dart');
+    String content_a1 = r'''
+import 'package:aaa/a1.dart';
+import '[invalid uri]';
 
-    when(generatedUriResolver.resolveAbsolute(uri, uri))
-        .thenReturn(generatedSource);
+export '[invalid uri]';
+export 'package:aaa/a2.dart';
 
-    FileState generatedFile = fileSystemState.getFileForUri(uri);
-    expect(generatedFile.path, generatedPath);
-    expect(generatedFile.uri, uri);
+part 'a3.dart';
+part '[invalid uri]';
+''';
+    provider.newFile(a, content_a1);
 
-    FileState templateFile = fileSystemState.getFileForPath(templatePath);
-    expect(templateFile.path, templatePath);
-    expect(templateFile.uri, uri);
+    FileState file = fileSystemState.getFileForPath(a);
 
-    expect(fileSystemState.getFilesForPath(templatePath), [templateFile]);
+    expect(_excludeSdk(file.importedFiles), hasLength(1));
+    expect(file.importedFiles[0].path, a1);
+    expect(file.importedFiles[0].uri, Uri.parse('package:aaa/a1.dart'));
+    expect(file.importedFiles[0].source, isNotNull);
+
+    expect(_excludeSdk(file.exportedFiles), hasLength(1));
+    expect(file.exportedFiles[0].path, a2);
+    expect(file.exportedFiles[0].uri, Uri.parse('package:aaa/a2.dart'));
+    expect(file.exportedFiles[0].source, isNotNull);
+
+    expect(_excludeSdk(file.partedFiles), hasLength(1));
+    expect(file.partedFiles[0].path, a3);
+    expect(file.partedFiles[0].uri, Uri.parse('package:aaa/a3.dart'));
+    expect(file.partedFiles[0].source, isNotNull);
   }
 
   test_getFileForPath_library() {
@@ -329,23 +392,23 @@ class A1 {}
 
     expect(_excludeSdk(file.importedFiles), hasLength(2));
     expect(file.importedFiles[0].path, a2);
-    expect(file.importedFiles[0].uri, FastUri.parse('package:aaa/a2.dart'));
+    expect(file.importedFiles[0].uri, Uri.parse('package:aaa/a2.dart'));
     expect(file.importedFiles[0].source, isNotNull);
     expect(file.importedFiles[1].path, b1);
-    expect(file.importedFiles[1].uri, FastUri.parse('package:bbb/b1.dart'));
+    expect(file.importedFiles[1].uri, Uri.parse('package:bbb/b1.dart'));
     expect(file.importedFiles[1].source, isNotNull);
 
     expect(file.exportedFiles, hasLength(2));
     expect(file.exportedFiles[0].path, b2);
-    expect(file.exportedFiles[0].uri, FastUri.parse('package:bbb/b2.dart'));
+    expect(file.exportedFiles[0].uri, Uri.parse('package:bbb/b2.dart'));
     expect(file.exportedFiles[0].source, isNotNull);
     expect(file.exportedFiles[1].path, a3);
-    expect(file.exportedFiles[1].uri, FastUri.parse('package:aaa/a3.dart'));
+    expect(file.exportedFiles[1].uri, Uri.parse('package:aaa/a3.dart'));
     expect(file.exportedFiles[1].source, isNotNull);
 
     expect(file.partedFiles, hasLength(1));
     expect(file.partedFiles[0].path, a4);
-    expect(file.partedFiles[0].uri, FastUri.parse('package:aaa/a4.dart'));
+    expect(file.partedFiles[0].uri, Uri.parse('package:aaa/a4.dart'));
 
     expect(_excludeSdk(file.directReferencedFiles), hasLength(5));
 
@@ -398,7 +461,7 @@ class A2 {}
 
     FileState file_a2 = fileSystemState.getFileForPath(a2);
     expect(file_a2.path, a2);
-    expect(file_a2.uri, FastUri.parse('package:aaa/a2.dart'));
+    expect(file_a2.uri, Uri.parse('package:aaa/a2.dart'));
 
     expect(file_a2.unlinked, isNotNull);
     expect(file_a2.unlinked.classes, hasLength(1));
@@ -445,7 +508,7 @@ part 'not-a2.dart';
 
   test_getFileForUri_packageVsFileUri() {
     String path = _p('/aaa/lib/a.dart');
-    var packageUri = FastUri.parse('package:aaa/a.dart');
+    var packageUri = Uri.parse('package:aaa/a.dart');
     var fileUri = provider.pathContext.toUri(path);
 
     // The files with `package:` and `file:` URIs are different.
@@ -464,6 +527,22 @@ part 'not-a2.dart';
     expect(files, [filePackageUri, fileFileUri]);
   }
 
+  test_hasUri() {
+    Uri uri = Uri.parse('package:aaa/foo.dart');
+    String templatePath = _p('/aaa/lib/foo.dart');
+    String generatedPath = _p('/generated/aaa/lib/foo.dart');
+
+    Source generatedSource = new _SourceMock();
+    when(generatedSource.fullName).thenReturn(generatedPath);
+    when(generatedSource.uri).thenReturn(uri);
+
+    when(generatedUriResolver.resolveAbsolute(uri, uri))
+        .thenReturn(generatedSource);
+
+    expect(fileSystemState.hasUri(templatePath), isFalse);
+    expect(fileSystemState.hasUri(generatedPath), isTrue);
+  }
+
   test_referencedNames() {
     String path = _p('/aaa/lib/a.dart');
     provider.newFile(
