@@ -13,10 +13,10 @@ import 'linker_test.dart' as linker_test;
 import 'name_filter_test.dart' as name_filter_test;
 import 'package_bundle_reader_test.dart' as package_bundle_reader_test;
 import 'prelinker_test.dart' as prelinker_test;
-import 'pub_summary_test.dart' as pub_summary_test;
 import 'resynthesize_ast_test.dart' as resynthesize_ast_test;
 import 'summarize_ast_strong_test.dart' as summarize_ast_strong_test;
 import 'summarize_ast_test.dart' as summarize_ast_test;
+import 'top_level_inference_test.dart' as top_level_inference_test;
 
 /// Utility for manually running all tests.
 main() {
@@ -28,9 +28,9 @@ main() {
     name_filter_test.main();
     package_bundle_reader_test.main();
     prelinker_test.main();
-    pub_summary_test.main();
     resynthesize_ast_test.main();
     summarize_ast_strong_test.main();
     summarize_ast_test.main();
+    top_level_inference_test.main();
   }, name: 'summary');
 }
