@@ -5,16 +5,16 @@
 part of dart.async;
 
 /** The onValue and onError handlers return either a value or a future */
-typedef dynamic/*T|Future<T>*/ _FutureOnValue<S, T>(S value);
+typedef FutureOr<T> _FutureOnValue<S, T>(S value);
 /** Test used by [Future.catchError] to handle skip some errors. */
-typedef bool _FutureErrorTest(var error);
+typedef bool _FutureErrorTest(Object error);
 /** Used by [WhenFuture]. */
-typedef _FutureAction();
+typedef dynamic _FutureAction();
 
 abstract class _Completer<T> implements Completer<T> {
   final _Future<T> future = new _Future<T>();
 
-  void complete([value]);
+  void complete([FutureOr<T> value]);
 
   void completeError(Object error, [StackTrace stackTrace]) {
     error = _nonNullError(error);
@@ -35,8 +35,7 @@ abstract class _Completer<T> implements Completer<T> {
 }
 
 class _AsyncCompleter<T> extends _Completer<T> {
-
-  void complete([value]) {
+  void complete([FutureOr<T> value]) {
     if (!future._mayComplete) throw new StateError("Future already completed");
     future._asyncComplete(value);
   }
@@ -47,7 +46,7 @@ class _AsyncCompleter<T> extends _Completer<T> {
 }
 
 class _SyncCompleter<T> extends _Completer<T> {
-  void complete([value]) {
+  void complete([FutureOr<T> value]) {
     if (!future._mayComplete) throw new StateError("Future already completed");
     future._complete(value);
   }
@@ -64,11 +63,9 @@ class _FutureListener<S, T> {
   static const int MASK_WHENCOMPLETE = 8;
   static const int STATE_CHAIN = 0;
   static const int STATE_THEN = MASK_VALUE;
-  // TODO(johnmccutchan): Remove the hard coded value. See #26030.
-  static const int STATE_THEN_ONERROR = 3;  // MASK_VALUE | MASK_ERROR.
+  static const int STATE_THEN_ONERROR = MASK_VALUE | MASK_ERROR;
   static const int STATE_CATCHERROR = MASK_ERROR;
-  // TODO(johnmccutchan): Remove the hard coded value. See #26030.
-  static const int STATE_CATCHERROR_TEST = 6;  // MASK_ERROR | MASK_TEST_ERROR.
+  static const int STATE_CATCHERROR_TEST = MASK_ERROR | MASK_TEST_ERROR;
   static const int STATE_WHENCOMPLETE = MASK_WHENCOMPLETE;
   // Listeners on the same future are linked through this link.
   _FutureListener _nextListener = null;
@@ -81,14 +78,14 @@ class _FutureListener<S, T> {
   // Used for error callbacks.
   final Function errorCallback;
 
-  _FutureListener.then(this.result,
-                       _FutureOnValue<S, T> onValue, Function errorCallback)
+  _FutureListener.then(
+      this.result, _FutureOnValue<S, T> onValue, Function errorCallback)
       : callback = onValue,
         errorCallback = errorCallback,
         state = (errorCallback == null) ? STATE_THEN : STATE_THEN_ONERROR;
 
-  _FutureListener.catchError(this.result,
-                             this.errorCallback, _FutureErrorTest test)
+  _FutureListener.catchError(
+      this.result, this.errorCallback, _FutureErrorTest test)
       : callback = test,
         state = (test == null) ? STATE_CATCHERROR : STATE_CATCHERROR_TEST;
 
@@ -104,19 +101,20 @@ class _FutureListener<S, T> {
   bool get hasErrorTest => (state == STATE_CATCHERROR_TEST);
   bool get handlesComplete => (state == STATE_WHENCOMPLETE);
 
-
   _FutureOnValue<S, T> get _onValue {
     assert(handlesValue);
-    return callback as Object /*=_FutureOnValue<S, T>*/;
+    return callback as Object/*=_FutureOnValue<S, T>*/;
   }
+
   Function get _onError => errorCallback;
   _FutureErrorTest get _errorTest {
     assert(hasErrorTest);
-    return callback as Object /*=_FutureErrorTest*/;
+    return callback as Object/*=_FutureErrorTest*/;
   }
+
   _FutureAction get _whenCompleteAction {
     assert(handlesComplete);
-    return callback as Object /*=_FutureAction*/;
+    return callback as Object/*=_FutureAction*/;
   }
 
   /// Whether this listener has an error callback.
@@ -127,27 +125,24 @@ class _FutureListener<S, T> {
     return _onError != null;
   }
 
-  dynamic/*T|Future<T>*/ handleValue(S sourceResult) {
-    return _zone.runUnary<dynamic/*T|Future<T>*/, S>(
-        _onValue, sourceResult);
+  FutureOr<T> handleValue(S sourceResult) {
+    return _zone.runUnary<FutureOr<T>, S>(_onValue, sourceResult);
   }
 
   bool matchesErrorTest(AsyncError asyncError) {
     if (!hasErrorTest) return true;
-    _FutureErrorTest test = _errorTest;
-    return _zone.runUnary<bool, dynamic>(_errorTest, asyncError.error);
+    return _zone.runUnary<bool, Object>(_errorTest, asyncError.error);
   }
 
-  dynamic/*T|Future<T>*/ handleError(AsyncError asyncError) {
+  FutureOr<T> handleError(AsyncError asyncError) {
     assert(handlesError && hasErrorCallback);
     if (errorCallback is ZoneBinaryCallback) {
       var typedErrorCallback = errorCallback as Object
-          /*=ZoneBinaryCallback<Object/*T|Future<T>*/, Object, StackTrace>*/;
-      return _zone.runBinary(typedErrorCallback,
-          asyncError.error,
-          asyncError.stackTrace);
+          /*=ZoneBinaryCallback<FutureOr<T>, Object, StackTrace>*/;
+      return _zone.runBinary(
+          typedErrorCallback, asyncError.error, asyncError.stackTrace);
     } else {
-      return _zone.runUnary<dynamic/*T|Future<T>*/, dynamic>(
+      return _zone.runUnary<FutureOr<T>, Object>(
           errorCallback, asyncError.error);
     }
   }
@@ -163,16 +158,20 @@ class _Future<T> implements Future<T> {
   /// [resultOrListeners] field holds a single-linked list of
   /// [_FutureListener] listeners.
   static const int _INCOMPLETE = 0;
+
   /// Pending completion. Set when completed using [_asyncComplete] or
   /// [_asyncCompleteError]. It is an error to try to complete it again.
   /// [resultOrListeners] holds listeners.
   static const int _PENDING_COMPLETE = 1;
+
   /// The future has been chained to another future. The result of that
   /// other future becomes the result of this future as well.
   /// [resultOrListeners] contains the source future.
   static const int _CHAINED = 2;
+
   /// The future has been completed with a value result.
   static const int _VALUE = 4;
+
   /// The future has been completed with an error result.
   static const int _ERROR = 8;
 
@@ -217,12 +216,12 @@ class _Future<T> implements Future<T> {
     _asyncCompleteError(error, stackTrace);
   }
 
-  bool get _mayComplete       => _state == _INCOMPLETE;
+  bool get _mayComplete => _state == _INCOMPLETE;
   bool get _isPendingComplete => _state == _PENDING_COMPLETE;
-  bool get _mayAddListener    => _state <= _PENDING_COMPLETE;
-  bool get _isChained         => _state == _CHAINED;
-  bool get _isComplete        => _state >= _VALUE;
-  bool get _hasError          => _state == _ERROR;
+  bool get _mayAddListener => _state <= _PENDING_COMPLETE;
+  bool get _isChained => _state == _CHAINED;
+  bool get _isComplete => _state >= _VALUE;
+  bool get _hasError => _state == _ERROR;
 
   void _setChained(_Future source) {
     assert(_mayAddListener);
@@ -230,38 +229,36 @@ class _Future<T> implements Future<T> {
     _resultOrListeners = source;
   }
 
-  Future<E> then<E>(
-      FutureOr<E> f(T value), { Function onError }) {
+  Future<E> then<E>(FutureOr<E> f(T value), {Function onError}) {
     Zone currentZone = Zone.current;
-    ZoneUnaryCallback registered;
     if (!identical(currentZone, _ROOT_ZONE)) {
       f = currentZone.registerUnaryCallback<FutureOr<E>, T>(f);
       if (onError != null) {
-        onError = _registerErrorHandler<T>(onError, currentZone);
+        onError = _registerErrorHandler<E>(onError, currentZone);
       }
     }
     return _thenNoZoneRegistration<E>(f, onError);
   }
 
   // This method is used by async/await.
-  Future<E> _thenNoZoneRegistration<E>(f(T value), Function onError) {
+  Future<E> _thenNoZoneRegistration<E>(
+      FutureOr<E> f(T value), Function onError) {
     _Future<E> result = new _Future<E>();
     _addListener(new _FutureListener<T, E>.then(result, f, onError));
     return result;
   }
 
-  Future<T> catchError(Function onError, { bool test(error) }) {
+  Future<T> catchError(Function onError, {bool test(error)}) {
     _Future<T> result = new _Future<T>();
     if (!identical(result._zone, _ROOT_ZONE)) {
       onError = _registerErrorHandler<T>(onError, result._zone);
       if (test != null) test = result._zone.registerUnaryCallback(test);
     }
-    _addListener(new _FutureListener<T, T>.catchError(
-        result, onError, test));
+    _addListener(new _FutureListener<T, T>.catchError(result, onError, test));
     return result;
   }
 
-  Future<T> whenComplete(action()) {
+  Future<T> whenComplete(dynamic action()) {
     _Future<T> result = new _Future<T>();
     if (!identical(result._zone, _ROOT_ZONE)) {
       action = result._zone.registerCallback<dynamic>(action);
@@ -294,13 +291,13 @@ class _Future<T> implements Future<T> {
 
   // This method is used by async/await.
   void _setValue(T value) {
-    assert(!_isComplete);  // But may have a completion pending.
+    assert(!_isComplete); // But may have a completion pending.
     _state = _VALUE;
     _resultOrListeners = value;
   }
 
   void _setErrorObject(AsyncError error) {
-    assert(!_isComplete);  // But may have a completion pending.
+    assert(!_isComplete); // But may have a completion pending.
     _state = _ERROR;
     _resultOrListeners = error;
   }
@@ -409,21 +406,21 @@ class _Future<T> implements Future<T> {
     target._setPendingComplete();
     try {
       source.then((value) {
-          assert(target._isPendingComplete);
-          // The "value" may be another future if the foreign future
-          // implementation is mis-behaving,
-          // so use _complete instead of _completeWithValue.
-          target._clearPendingComplete();  // Clear this first, it's set again.
-          target._complete(value);
-        },
-        // TODO(floitsch): eventually we would like to make this non-optional
-        // and dependent on the listeners of the target future. If none of
-        // the target future's listeners want to have the stack trace we don't
-        // need a trace.
-        onError: (error, [stackTrace]) {
-          assert(target._isPendingComplete);
-          target._completeError(error, stackTrace);
-        });
+        assert(target._isPendingComplete);
+        // The "value" may be another future if the foreign future
+        // implementation is mis-behaving,
+        // so use _complete instead of _completeWithValue.
+        target._clearPendingComplete(); // Clear this first, it's set again.
+        target._complete(value);
+      },
+          // TODO(floitsch): eventually we would like to make this non-optional
+          // and dependent on the listeners of the target future. If none of
+          // the target future's listeners want to have the stack trace we don't
+          // need a trace.
+          onError: (error, [stackTrace]) {
+        assert(target._isPendingComplete);
+        target._completeError(error, stackTrace);
+      });
     } catch (e, s) {
       // This only happens if the `then` call threw synchronously when given
       // valid arguments.
@@ -438,7 +435,7 @@ class _Future<T> implements Future<T> {
   // Take the value (when completed) of source and complete target with that
   // value (or error). This function expects that source is a _Future.
   static void _chainCoreFuture(_Future source, _Future target) {
-    assert(target._mayAddListener);  // Not completed, not already chained.
+    assert(target._mayAddListener); // Not completed, not already chained.
     while (source._isChained) {
       source = source._chainSource;
     }
@@ -453,17 +450,17 @@ class _Future<T> implements Future<T> {
     }
   }
 
-  void _complete(value) {
+  void _complete(FutureOr<T> value) {
     assert(!_isComplete);
-    if (value is Future) {
-      if (value is _Future) {
+    if (value is Future<T>) {
+      if (value is _Future<T>) {
         _chainCoreFuture(value, this);
       } else {
         _chainForeignFuture(value, this);
       }
     } else {
       _FutureListener listeners = _removeListeners();
-      _setValue(value as Object /*=T*/);
+      _setValue(value as Object/*=T*/);
       _propagateToListeners(this, listeners);
     }
   }
@@ -477,7 +474,7 @@ class _Future<T> implements Future<T> {
     _propagateToListeners(this, listeners);
   }
 
-  void _completeError(error, [StackTrace stackTrace]) {
+  void _completeError(Object error, [StackTrace stackTrace]) {
     assert(!_isComplete);
 
     _FutureListener listeners = _removeListeners();
@@ -485,7 +482,7 @@ class _Future<T> implements Future<T> {
     _propagateToListeners(this, listeners);
   }
 
-  void _asyncComplete(value) {
+  void _asyncComplete(FutureOr<T> value) {
     assert(!_isComplete);
     // Two corner cases if the value is a future:
     //   1. the future is already completed and an error.
@@ -498,30 +495,27 @@ class _Future<T> implements Future<T> {
     // unhandled error, even though we know we are already going to listen to
     // it.
 
-    if (value is Future) {
-      // Assign to typed variables so we get earlier checks in checked mode.
-      Future<T> typedFuture = value as Object /*=Future<T>*/;
-      if (typedFuture is _Future) {
-        _Future<T> coreFuture = typedFuture;
-        if (coreFuture._hasError) {
+    if (value is Future<T>) {
+      if (value is _Future<T>) {
+        if (value._hasError) {
           // Case 1 from above. Delay completion to enable the user to register
           // callbacks.
           _setPendingComplete();
           _zone.scheduleMicrotask(() {
-            _chainCoreFuture(coreFuture, this);
+            _chainCoreFuture(value, this);
           });
         } else {
-          _chainCoreFuture(coreFuture, this);
+          _chainCoreFuture(value, this);
         }
       } else {
         // Case 2 from above. Chain the future immediately.
         // Note that we are still completing asynchronously (through
         // _chainForeignFuture).
-        _chainForeignFuture(typedFuture, this);
+        _chainForeignFuture(value, this);
       }
       return;
     }
-    T typedValue = value as Object /*=T*/;
+    T typedValue = value as Object/*=T*/;
 
     _setPendingComplete();
     _zone.scheduleMicrotask(() {
@@ -549,8 +543,8 @@ class _Future<T> implements Future<T> {
       if (listeners == null) {
         if (hasError) {
           AsyncError asyncError = source._error;
-          source._zone.handleUncaughtError(
-              asyncError.error, asyncError.stackTrace);
+          source._zone
+              .handleUncaughtError(asyncError.error, asyncError.stackTrace);
         }
         return;
       }
@@ -583,8 +577,8 @@ class _Future<T> implements Future<T> {
         if (hasError && !source._zone.inSameErrorZone(zone)) {
           // Don't cross zone boundaries with errors.
           AsyncError asyncError = source._error;
-          source._zone.handleUncaughtError(
-              asyncError.error, asyncError.stackTrace);
+          source._zone
+              .handleUncaughtError(asyncError.error, asyncError.stackTrace);
           return;
         }
 
@@ -659,7 +653,6 @@ class _Future<T> implements Future<T> {
           }
         }
 
-
         if (listener.handlesComplete) {
           handleWhenCompleteCallback();
         } else if (!hasError) {
@@ -710,14 +703,14 @@ class _Future<T> implements Future<T> {
     }
   }
 
-  Future<T> timeout(Duration timeLimit, {onTimeout()}) {
+  Future<T> timeout(Duration timeLimit, {FutureOr<T> onTimeout()}) {
     if (_isComplete) return new _Future.immediate(this);
     _Future<T> result = new _Future<T>();
     Timer timer;
     if (onTimeout == null) {
       timer = new Timer(timeLimit, () {
-        result._completeError(new TimeoutException("Future not completed",
-                                                   timeLimit));
+        result._completeError(
+            new TimeoutException("Future not completed", timeLimit));
       });
     } else {
       Zone zone = Zone.current;
