@@ -10,10 +10,11 @@ import 'compiler_options.dart';
 import 'dart:async';
 
 import 'package:analyzer/src/generated/source.dart' show SourceKind;
+import 'package:analyzer/src/generated/engine.dart' show AnalysisOptionsImpl;
 import 'package:analyzer/src/summary/package_bundle_reader.dart'
     show InSummarySource;
 // TODO(sigmund): move loader logic under front_end/lib/src/kernel/
-import 'package:kernel/analyzer/loader.dart';
+import 'package:analyzer/src/kernel/loader.dart';
 import 'package:kernel/kernel.dart';
 import 'package:source_span/source_span.dart' show SourceSpan;
 
@@ -37,12 +38,17 @@ import 'package:source_span/source_span.dart' show SourceSpan;
 /// needed to access the contents of method bodies).
 Future<Program> kernelForProgram(Uri source, CompilerOptions options) async {
   var loader = await _createLoader(options, entry: source);
+
+  if (options.compileSdk) {
+    options.additionalLibraries.forEach(loader.loadLibrary);
+  }
+
   // TODO(sigmund): merge what we have in loadEverything and the logic below in
   // kernelForBuildUnit so there is a single place where we crawl for
   // dependencies.
-  Program program = loader.loadProgram(source, compileSdk: options.compileSdk);
+  loader.loadProgram(source, compileSdk: options.compileSdk);
   _reportErrors(loader.errors, options.onError);
-  return program;
+  return loader.program;
 }
 
 /// Generates a kernel representation for a build unit.
@@ -80,8 +86,8 @@ Future<Program> kernelForProgram(Uri source, CompilerOptions options) async {
 /// obtained from?
 Future<Program> kernelForBuildUnit(
     List<Uri> sources, CompilerOptions options) async {
-  var repository = new Repository();
-  var loader = await _createLoader(options, repository: repository);
+  var program = new Program();
+  var loader = await _createLoader(options, program: program);
   var context = loader.context;
 
   // Process every library in the build unit.
@@ -100,10 +106,10 @@ Future<Program> kernelForBuildUnit(
   // TODO(sigmund): we should look for dependencies using import, export, and
   // part directives intead of relying on the dartk-loader.  In particular, if a
   // library is imported but not used, the logic below will not detect it.
-  for (int i = 0; i < repository.libraries.length; ++i) {
-    // Note: we don't use a for-in loop because repository.libraries grows as
+  for (int i = 0; i < program.libraries.length; ++i) {
+    // Note: we don't use a for-in loop because program.libraries grows as
     // the loader processes libraries.
-    var lib = repository.libraries[i];
+    var lib = program.libraries[i];
     var source = context.sourceFactory.forUri2(lib.importUri);
     if (source is InSummarySource) continue;
     if (options.chaseDependencies) {
@@ -116,7 +122,6 @@ Future<Program> kernelForBuildUnit(
     }
   }
 
-  Program program = new Program(repository.libraries);
   _reportErrors(loader.errors, options.onError);
   return program;
 }
@@ -126,13 +131,26 @@ Future<Program> kernelForBuildUnit(
 /// If [options] contain no configuration to resolve `.packages`, the [entry]
 /// file will be used to search for a `.packages` file.
 Future<DartLoader> _createLoader(CompilerOptions options,
-    {Repository repository, Uri entry}) async {
+    {Program program, Uri entry}) async {
   var kernelOptions = _convertOptions(options);
   var packages = await createPackages(
       _uriToPath(options.packagesFileUri, options),
       discoveryPath: entry?.path);
-  return new DartLoader(
-      repository ?? new Repository(), kernelOptions, packages);
+  var loader =
+      new DartLoader(program ?? new Program(), kernelOptions, packages);
+  var patchPaths = <String, List<String>>{};
+
+  // TODO(sigmund,paulberry): use ProcessedOptions so that we can resolve the
+  // URIs correctly even if sdkRoot is inferred and not specified explicitly.
+  String resolve(Uri patch) =>
+      options.fileSystem.context.fromUri(options.sdkRoot.resolveUri(patch));
+
+  options.targetPatches.forEach((uri, patches) {
+    patchPaths['$uri'] = patches.map(resolve).toList();
+  });
+  AnalysisOptionsImpl analysisOptions = loader.context.analysisOptions;
+  analysisOptions.patchPaths = patchPaths;
+  return loader;
 }
 
 DartOptions _convertOptions(CompilerOptions options) {
@@ -144,6 +162,7 @@ DartOptions _convertOptions(CompilerOptions options) {
       sdkSummary:
           options.compileSdk ? null : _uriToPath(options.sdkSummary, options),
       packagePath: _uriToPath(options.packagesFileUri, options),
+      customUriMappings: options.uriOverride,
       declaredVariables: options.declaredVariables);
 }
 
@@ -157,7 +176,7 @@ void _reportErrors(List errors, ErrorHandler onError) {
 String _uriToPath(Uri uri, CompilerOptions options) {
   if (uri == null) return null;
   if (uri.scheme != 'file') {
-    throw new StateError('Only file URIs are supported');
+    throw new StateError('Only file URIs are supported: $uri');
   }
   return options.fileSystem.context.fromUri(uri);
 }
