@@ -195,19 +195,22 @@
 library dart.io;
 
 import 'dart:async';
-import 'dart:_internal';
-import 'dart:collection' show HashMap,
-                              HashSet,
-                              Queue,
-                              ListQueue,
-                              LinkedList,
-                              LinkedListEntry,
-                              UnmodifiableMapView;
+import 'dart:_internal' hide Symbol;
+import 'dart:collection'
+    show
+        HashMap,
+        HashSet,
+        Queue,
+        ListQueue,
+        LinkedList,
+        LinkedListEntry,
+        UnmodifiableMapView;
 import 'dart:convert';
-import 'dart:developer';
+import 'dart:developer' hide log;
 import 'dart:isolate';
 import 'dart:math';
 import 'dart:typed_data';
+import 'dart:nativewrappers';
 
 part 'bytes_builder.dart';
 part 'common.dart';
